Module replay

Module replay 

Replay items for action replay with await markers.

This module provides types for replay files that can include _await markers to pause replay until async effects complete.

Example JSON

[
  {"SearchQuerySubmit": "Cabo Verde"},
  {"_await": "SearchDidLoad"},
  {"SearchSelect": 0},
  "SearchConfirm",
  {"_await_any": ["WeatherDidLoad", "WeatherDidError"]}
]

Enums

ReplayItem
A replay item: either an action or an await marker.